<?php

/**
 * Invoke snipcart remote API
 *
 * @param string $method
 *   the HTTP method ('GET' or 'PUT')
 * @param string $endpoint
 *   the API endpoint (only 'orders' at this point)
 * @param string $token
 *   the order token, if needed
 * @param object $body
 *   the request body, for PUT requests
 * @param string $relation
 *   the endpoint relation if needed (for now, only 'notifications', for 'orders' endpoint)
 *
 * @return object|false
 *   the API response or FALSE if the call fails
 */
function snipcart_api_invoke($method, $endpoint = 'orders', $token = NULL, $body = NULL, $relation = NULL) {

  $url = implode('/',
    array_merge(
      array(
        'https://app.snipcart.com/api',
        $endpoint
      ),
      !empty($token) ? array($token) : array(),
      !empty($relation) ? array($relation) : array()
    )
  );

  $client = new GuzzleHttp\Client();

  try {
    $res = $client->request($method, $url, [
        'auth' => [variable_get('snipcart_api_key'), ''],
        'headers' => [
          'Accept' => 'application/json',
        ],
      ] + (!empty($body) ? ['json' => $body] : []));
  }catch(Exception $e){
    return FALSE;
  }

  return json_decode($res->getBody()->getContents());

}
