<?php

/**
 * Convert a Commerce product to its corresponding Snipcart representation.
 *
 * @param stdClass $product
 *   a Commerce product entity
 *
 * @return stdClass
 *   a Snipcart representation of the product, as an object
 */
function snipcart_get_product($product){

  $product_wrapper = entity_metadata_wrapper('commerce_product', $product);

  $currency = $product_wrapper->commerce_price->currency_code->value();
  $amount = $product_wrapper->commerce_price->amount_decimal->value();

  if(module_exists('commerce_vat_reference')) {
    $fields = field_info_fields();
    $instances = field_info_instances('commerce_product', $product->type);
    foreach ($instances as $field_name => $instance) {
      if ($fields[$field_name]['type'] == 'commerce_vat_rate_reference') {
        $rate = commerce_vat_rate_load(entity_metadata_wrapper('commerce_product', $product)->{$field_name}->value());
        if($rate){
          $rates[] = $rate['price_component'];
        }
      }
    }
  }

  $snipcart_product = (object) array(
    'id' => $product_wrapper->getIdentifier(),
    'name' => $product_wrapper->label(),
    'url' => services_resource_uri(array('snipcart_product', $product->product_id)),
    'price' => array(strtolower($currency) => $amount),
    'taxes' => $rates,
  );

  if(module_exists('commerce_stock')){
    $snipcart_product->inventoryManagementMethod = "Single";
    $snipcart_product->allowOutOfStockPurchases = false;
    $snipcart_product->stock = round($product_wrapper->commerce_stock->value());
  }

  drupal_alter('snipcart_product_data', $snipcart_product, $product);

  return $snipcart_product;

}
