<?php

/**
 * @file
 * Services API hooks & callbacks
 */


/**
 * Implements hook_services_resource().
 */
function snipcart_services_resources() {

  $resource = array(
    'snipcart_product' => array(
      'operations' => array(
        'retrieve' => array(
          'file' => array(
            'type' => 'inc',
            'module' => 'snipcart',
            'name' => 'snipcart.services'
          ),
          'callback' => '_snipcart_services_product_retrieve',
          'access callback' => '_snipcart_services_product_access',
          'access arguments' => array(),
          'access arguments append' => TRUE,
          'args' => array(
            array(
              'name' => 'id',
              'optional' => FALSE,
              'source' => array('path' => 0),
              'type' => 'string',
              'description' => 'The product id',
            ),
          ),
        ),
      ),
    ),
  );

  return $resource;

}


/**
 * Snipcart product resource access callback.
 *
 * @param array $args
 *   Services callback arguments
 * @return bool
 *   TRUE if access is granted, FALSE otherwise
 */
function _snipcart_services_product_access($args) {
  // validate snipcart request
  if (!snipcart_validate_request()) {
    return FALSE;
  }
  $product_id = reset($args);
  if (!$product_id) {
    return FALSE;
  }
  $product = commerce_product_load($product_id);
  if (!$product) {
    return FALSE;
  }
  return TRUE;
}


/**
 * Snipcart product resource retrieve callback.
 *
 * The resulting array is intended to be serialized in JSON
 * by the Services API.
 *
 * @param int $product_id
 *   the product id
 * @return stdClass
 *   a Snipcart representation of the product, as an object
 * @throws \ServicesException
 *   if an unrecoverable error occurs
 */
function _snipcart_services_product_retrieve($product_id){

  $product = commerce_product_load($product_id);

  if (!$product) {
    return services_error('Product not found', 404);
  }

  module_load_include('inc', 'snipcart', 'snipcart.product');
  $product = snipcart_get_product($product);
  drupal_alter('snipcart_services_product', $product);
  return $product;

}
