<?php

/**
 * Menu callback handler for Snipcart webhooks.
 */
function snipcart_webhooks_handler(){
  $received = file_get_contents("php://input");
  $received = json_decode($received);
  switch($received->eventName){
    case 'shippingrates.fetch':
      // build a temporary commerce_order from Snipcart order data
      $order = snipcart_create_order($received->content);

      // invoke commerce_shipping rules
      rules_invoke_event('commerce_shipping_collect_rates', $order);

      // build array of shipping method for Snipcart
      $snipcart_shipping_rates = array();
      if (!empty($order->shipping_rates)) {
        foreach ($order->shipping_rates as $rate_id => $rate) {
          $rate_wrapper = entity_metadata_wrapper('commerce_line_item', $rate);
          $snipcart_shipping_rates[] = array(
            'cost' => commerce_currency_amount_to_decimal(
              $rate_wrapper->commerce_unit_price->value()['amount'],
              $rate_wrapper->commerce_unit_price->value()['currency_code']
            ),
            'description' => $rate->line_item_label,
          );
        }
      }


      $errors = [];
      drupal_alter('snipcart_webhook_shippingrates', $snipcart_shipping_rates, $errors);
      drupal_add_http_header('Content-Type', 'application/json');
      if(!count($errors)) {
        print json_encode(array('rates' => $snipcart_shipping_rates));
      }else{
        print json_encode(array('errors' => $errors));
      }
      exit;

    case 'taxes.calculate':
      // build a temporary commerce_order from Snipcart order data
      $order = snipcart_create_order($received->content);

      $languages = language_list();
      if(!empty($languages[$received->content->lang])){
        $language = $languages[$received->content->lang];
      }
      else{
        $language = language_default();
      }

      $wrapper = entity_metadata_wrapper('commerce_order', $order);
      $order_total = $wrapper->commerce_order_total->value();

      drupal_add_http_header('Content-Type', 'application/json');
      $result = array(
        'taxes' =>
          array_values(array_map(function ($item) use($language) {
            $name = !empty($item['price']['data']['vat_rate_info']['rate'])
              ? t(($item['included'] ? 'Including VAT @percent' : 'VAT @percent'),
                array('@percent' => ($item['price']['data']['vat_rate_info']['rate'] * 100) . '%'),
                array('langcode' => $language->language)
              )
              : $item['name'];
            return array(
              'name' => $name,
              'amount' => $item['price']['amount'] / 100,
              'numberForInvoice' => '',
              'includedInPrice' => $item['included'],
            );
          },
            array_filter($order_total['data']['components'], function ($item) {
              return preg_match('/^vat\|/', $item['name']);
            })))
      );

      print json_encode($result);
      exit;

    case 'order.completed':
      // sync order
      $order = snipcart_create_order($received->content);
      commerce_order_status_update($order, 'pending', TRUE);
      $order->created = strtotime($received->content->completionDate);
      commerce_order_save($order);
      drupal_add_http_header('Content-Type', 'application/json');
      module_invoke_all('snipcart_webhook_order_completed', $order, $received);
      print json_encode((object) array('sync' => 'OK'));
      exit;

    case 'order.status.changed':
      // sync order
      if($received->to === 'Shipped') {
        $order = snipcart_create_order($received->content);
        commerce_order_status_update($order, 'completed');
      }
      drupal_add_http_header('Content-Type', 'application/json');
      print json_encode((object) array('sync' => 'OK'));
      exit;

  }
}
